==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/BarSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VerticalAnchoredCategorySeriesDescriptionMetadata } from "./VerticalAnchoredCategorySeriesDescriptionMetadata";
import { BarSeriesDescription } from "./BarSeriesDescription";
/**
 * @hidden
 */
var BarSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BarSeriesDescriptionMetadata, _super);
    function BarSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BarSeriesDescriptionMetadata.b = function (a) {
        if (BarSeriesDescriptionMetadata.a == null) {
            BarSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BarSeriesDescriptionMetadata.c(BarSeriesDescriptionMetadata.a);
        }
        if (a.g(BarSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(BarSeriesDescriptionMetadata.a);
    };
    BarSeriesDescriptionMetadata.c = function (a) {
        VerticalAnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    BarSeriesDescriptionMetadata.d = function (a) {
        BarSeriesDescriptionMetadata.b(a);
        a.u("BarSeries", function () { return new BarSeriesDescription(); });
        a.t("BarSeries", BarSeriesDescriptionMetadata.a);
    };
    BarSeriesDescriptionMetadata.$t = markType(BarSeriesDescriptionMetadata, 'BarSeriesDescriptionMetadata');
    BarSeriesDescriptionMetadata.a = null;
    return BarSeriesDescriptionMetadata;
}(Base));
export { BarSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/BarSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VerticalAnchoredCategorySeriesDescriptionMetadata } from "./VerticalAnchoredCategorySeriesDescriptionMetadata";
import { BarSeriesDescription } from "./BarSeriesDescription";
/**
 * @hidden
 */
var BarSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(BarSeriesDescriptionMetadata, _super);
    function BarSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BarSeriesDescriptionMetadata.b = function (a) {
        if (BarSeriesDescriptionMetadata.a == null) {
            BarSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BarSeriesDescriptionMetadata.c(BarSeriesDescriptionMetadata.a);
        }
        if (a.j(BarSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(BarSeriesDescriptionMetadata.a);
    };
    BarSeriesDescriptionMetadata.c = function (a) {
        VerticalAnchoredCategorySeriesDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    BarSeriesDescriptionMetadata.d = function (a) {
        BarSeriesDescriptionMetadata.b(a);
        a.aa("BarSeries", function () { return new BarSeriesDescription(); });
        a.z("BarSeries", BarSeriesDescriptionMetadata.a);
    };
    BarSeriesDescriptionMetadata.$t = markType(BarSeriesDescriptionMetadata, 'BarSeriesDescriptionMetadata');
    BarSeriesDescriptionMetadata.a = null;
    return BarSeriesDescriptionMetadata;
}(Base));
export { BarSeriesDescriptionMetadata };
